/*
 *  $Id: cons-default.h,v 1.3 1999-12-01 00:19:34-08 bryan Exp $
 *
 *  Copyright GNAC, Inc., 1998
 *
 *  Maintainer/Enhancer: Bryan Stansell (bryan@gnac.com)
 */

/*
--- Socket used to communicate
#define PORT		782
    or
#define SERVICE		"conserver"

--- Hostname of console server
#define HOST		"console"

--- Config file path
#define CONFIG		"/etc/conserver.cf"

--- Password file path
#define PASSWD_FILE	"/etc/conserver.passwd"

--- Number of consoles per child process
#define MAXMEMB		8

--- Number of child processes
#define MAXGRP		32

--- Clear parity (high-bit) [true/false setting]
#define CPARITY		1
*/
